### -*- coding: utf-8 -*- #############################################
# Разработано компанией Ключевые Решения (http://keysolutions.ru/)
# Все права защищены, 2006-2007
#
# Developed by Key Solutions (http://keysolutions.ru/)
# All right reserved, 2006-2007
#######################################################################
"""Interfaces for the Zope 3 based mailer package

$Id: interfaces.py 23861 2007-11-25 00:13:00Z xen $
"""
__author__  = "Anatoly Zaretsky"
__license__ = "ZPL"
__version__ = "$Revision: 23861 $"
__date__ = "$Date: 2007-11-25 02:13:00 +0200 (Sun, 25 Nov 2007) $"

from zope.interface import Interface
from zope.schema import Choice

from ks.mailer import _

class IMailer(Interface):

    template = Choice(
        title=_(u"Template"),
        vocabulary="Message Template Vocabulary")

    def execute(**kw):
        pass


class ITemplateAdaptable(Interface):
    pass


class ITemplate(ITemplateAdaptable):

    def __call__(**kw):
        pass



### -*- coding: utf-8 -*- #############################################
# Разработано компанией Ключевые Решения (http://keysolutions.ru/)
# Все права защищены, 2006-2007
#
# Developed by Key Solutions (http://keysolutions.ru/)
# All right reserved, 2006-2007
#######################################################################

# Make it a Python package

import zope.i18nmessageid
_ = zope.i18nmessageid.MessageFactory('ks')



### -*- coding: utf-8 -*- #############################################
# Разработано компанией Ключевые Решения (http://keysolutions.ru/)
# Все права защищены, 2006-2007
#
# Developed by Key Solutions (http://keysolutions.ru/)
# All right reserved, 2006-2007
#######################################################################
"""The MailTemplate vocabulary class.

$Id: vocabulary.py 23861 2007-11-25 00:13:00Z xen $
"""
__author__  = "Anatoly Zaretsky"
__license__	= "ZPL"
__version__ = "$Revision: 23861 $"
__date__ = "$Date: 2007-11-25 02:13:00 +0200 (Sun, 25 Nov 2007) $"

from zope.interface import classProvides
from zope.schema.interfaces import IVocabularyFactory
from zope.app.component.vocabulary import UtilityVocabulary

from interfaces import ITemplateAdaptable

class MessageTemplateVocabulary(UtilityVocabulary):
    classProvides(IVocabularyFactory)
    interface = ITemplateAdaptable
    nameOnly = True



### -*- coding: utf-8 -*- #############################################
# Разработано компанией Ключевые Решения (http://keysolutions.ru/)
# Все права защищены, 2006-2007
#
# Developed by Key Solutions (http://keysolutions.ru/)
# All right reserved, 2006-2007
#######################################################################
"""IMailerSMTPAnnotation to IMailerSMTP adapter for the Zope 3 based mailersmtp package

$Id: templateadapter.py 23861 2007-11-25 00:13:00Z xen $
"""
__author__  = "Anatoly Zaretsky"
__license__ = "ZPL"
__version__ = "$Revision: 23861 $"
__date__ = "$Date: 2007-11-25 02:13:00 +0200 (Sun, 25 Nov 2007) $"


from zope.component import getUtility

from interfaces import ITemplateAdaptable, ITemplate
from zope.security.management import getInteraction


def templateadapter(context):

    def f(**kw):
        if 'request' in kw:
            return context.render(**kw)
        else:
            #XXX
            request = getInteraction().participations[0]
            return context.render(request=request, **kw)
    return f

def getTemplate(name, context):
    return ITemplate(getUtility(ITemplateAdaptable, name=name, context=context))



#!/usr/bin/env python
### -*- coding: utf-8 -*- #############################################
#######################################################################
"""Setup for ks.mailer package

$Id: setup.py 35256 2007-12-05 18:52:17Z anatoly $
"""

import os

from setuptools import setup, find_packages

def read(*rnames):
    return open(os.path.join(os.path.dirname(__file__), *rnames)).read()

def details():
    try:
        return '\n' + \
        'Detailed Documentation\n'
        '**********************\n'
        + '\n' + \
        read('src', 'ks', 'mailer', 'README.txt')
    except IOError:
        return ''

long_description = (
    read('README.txt')
    + '\n' +
    read('CHANGES.txt')
    + details()
    )

setup(
    name = 'ks.mailer',
    version = '1.0.1',
    url = 'http://code.keysolutionscorp.com/downloads/public/pypi/ks.mailer',
    license = 'ZPL 2.1',
    description = 'Base classes and interfaces for message creation utility',
    author = 'Key Solutions Development TEAM',
    author_email = 'ksd-team@keysolutions.ru',
    classifiers = [
        'Intended Audience :: Developers',
        'License :: OSI Approved :: Zope Public License',
        'Programming Language :: Python',
        'Natural Language :: English',
        'Operating System :: OS Independent',
        'Topic :: Internet :: WWW/HTTP',
        'Topic :: Software Development',
        'Framework :: Zope3',
        ],
    long_description = long_description,
    packages = find_packages('src'),
    package_dir = {'': 'src'},
    namespace_packages = ['ks',],
    install_requires=[x.strip() for x in open("DEPENDENCIES.txt").read().split("\n") if x.strip()],
    extras_require = dict(
        test = ['zope.testing',
                'ZODB3'],
        ),
    include_package_data = True,
    zip_safe = False,
    )
